@@ -7,7 +7,7 @@ COMPONENT_TEXT = 0x0000000000000001
 COMPONENT_TEXT_AREA = 0x0000000000000002
 
 COMPONENT_INT = 0x0000000000000010
-COMPONENT_SLIDER = 0x0000000000000020
+COMPONENT_INT_SLIDER = 0x0000000000000020
 
 COMPONENT_FLOAT = 0x0000000000000100
 COMPONENT_FLOAT_SLIDER = 0x0000000000000200
